# Higgs Asset Boom Strategy Platform API

This project is intended to support and accelerate the investment/trading strategy development procedures at Hangzhou Higgs Asset Management Co., Ltd. (HiggsAsset)

The project provides the following functionalities:

## Data Access

By providing a simple and easy-to-use python API, which integrates all data infrustructure at HiggsAsset, quants can easily access any available structured(via the form of pandas DataFrame) or unstructured data.

## Feature Generation and Integration

## Feature Analysis

## Model Evaluation

